==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/xcontent/SpanOrQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.xcontent;

import org.elasticsearch.index.query.QueryBuilderException;
import org.elasticsearch.util.xcontent.builder.XContentBuilder;

import java.io.IOException;
import java.util.ArrayList;

/**
 * @author kimchy (shay.banon)
 */
public class SpanOrQueryBuilder extends BaseQueryBuilder implements XContentSpanQueryBuilder {

    private ArrayList<XContentSpanQueryBuilder> clauses = new ArrayList<XContentSpanQueryBuilder>();

    private float boost = -1;

    public SpanOrQueryBuilder clause(XContentSpanQueryBuilder clause) {
        clauses.add(clause);
        return this;
    }

    public SpanOrQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override protected void doXContent(XContentBuilder builder, Params params) throws IOException {
        if (clauses.isEmpty()) {
            throw new QueryBuilderException("Must have at least one clause when building a spanOr query");
        }
        builder.startObject(SpanOrQueryParser.NAME);
        builder.startArray("clauses");
        for (XContentSpanQueryBuilder clause : clauses) {
            clause.toXContent(builder, params);
        }
        builder.endArray();
        if (boost != -1) {
            builder.field("boost", boost);
        }
        builder.endObject();
    }
}

==> v0.9.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/xcontent/SpanOrQueryBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.xcontent;

import org.elasticsearch.common.xcontent.builder.XContentBuilder;
import org.elasticsearch.index.query.QueryBuilderException;

import java.io.IOException;
import java.util.ArrayList;

/**
 * @author kimchy (shay.banon)
 */
public class SpanOrQueryBuilder extends BaseQueryBuilder implements XContentSpanQueryBuilder {

    private ArrayList<XContentSpanQueryBuilder> clauses = new ArrayList<XContentSpanQueryBuilder>();

    private float boost = -1;

    public SpanOrQueryBuilder clause(XContentSpanQueryBuilder clause) {
        clauses.add(clause);
        return this;
    }

    public SpanOrQueryBuilder boost(float boost) {
        this.boost = boost;
        return this;
    }

    @Override protected void doXContent(XContentBuilder builder, Params params) throws IOException {
        if (clauses.isEmpty()) {
            throw new QueryBuilderException("Must have at least one clause when building a spanOr query");
        }
        builder.startObject(SpanOrQueryParser.NAME);
        builder.startArray("clauses");
        for (XContentSpanQueryBuilder clause : clauses) {
            clause.toXContent(builder, params);
        }
        builder.endArray();
        if (boost != -1) {
            builder.field("boost", boost);
        }
        builder.endObject();
    }
}
